@@ -38,7 +38,6 @@
 #endif
 
 
-#include <klocale.h>
 #include <QTimer>
 /*
   I am using a fixed MAX_MIXDEVS #define here.
@@ -106,14 +105,14 @@ int Mixer_OSS::open()
 {
     QString finalDeviceName;
     finalDeviceName = deviceName( m_devnum );
-  kDebug() << "OSS open() " << finalDeviceName;
-    if ((m_fd= ::open( finalDeviceName.toAscii().data(), O_RDWR)) < 0)
+  qCDebug(KMIX_LOG) << "OSS open() " << finalDeviceName;
+    if ((m_fd= ::open( finalDeviceName.toLatin1().data(), O_RDWR)) < 0)
     {
         if ( errno == EACCES )
         return Mixer::ERR_PERM;
         else {
             finalDeviceName = deviceNameDevfs( m_devnum );
-            if ((m_fd= ::open( finalDeviceName.toAscii().data(), O_RDWR)) < 0)
+            if ((m_fd= ::open( finalDeviceName.toLatin1().data(), O_RDWR)) < 0)
             {
                 if ( errno == EACCES )
                     return Mixer::ERR_PERM;
@@ -128,7 +127,7 @@ int Mixer_OSS::open()
         QString msg("No UDI found for '");
         msg += finalDeviceName;
         msg += "'. Hotplugging not possible";
-        kDebug(67100) << msg;
+        qCDebug(KMIX_LOG) << msg;
     }
       int devmask, recmask, i_recsrc, stereodevs;
       // Mixer is open. Now define properties
@@ -146,7 +145,7 @@ int Mixer_OSS::open()
             {
               if( devmask & ( 1 << idx ) ) // device active?
                 {
-                  Volume playbackVol( 100, 1, true, false );
+                  Volume playbackVol( 100, 0, true, false );
 		  playbackVol.addVolumeChannel(VolumeChannel(Volume::LEFT));
 		  if ( stereodevs & ( 1 << idx ) )
 		    playbackVol.addVolumeChannel(VolumeChannel(Volume::RIGHT));
@@ -163,7 +162,7 @@ int Mixer_OSS::open()
                   // Tutorial: Howto add a simple capture switch
                   if ( recmask & ( 1 << idx ) ) {
                      // can be captured => add capture volume, with no capture volume
-                     Volume captureVol( 100, 1, true, true );
+                     Volume captureVol( 100, 0, true, true );
                      md->addCaptureVolume(captureVol);
                  }
 
@@ -261,7 +260,7 @@ void print_recsrc(int recsrc)
 		else
 		  msg += '.';
 	}	
-	kDebug() << msg;
+	qCDebug(KMIX_LOG) << msg;
 }
 
 int Mixer_OSS::setRecsrcToOSS( const QString& id, bool on )
@@ -343,7 +342,7 @@ void Mixer_OSS::errormsg(int mixer_error)
 {
 	QString l_s_errText;
 	l_s_errText = errorText(mixer_error);
-	kError() << l_s_errText << "\n";
+	qCCritical(KMIX_LOG) << l_s_errText << "\n";
 }
 
 
@@ -373,7 +372,7 @@ int Mixer_OSS::readVolumeFromHW( const QString& id, shared_ptr<MixDevice> md )
 			int volRight = ((volume>>8) & 0x7f);
 //
 //			if ( md->id() == "0" )
-//				kDebug() << md->id() << ": " << "volLeft=" << volLeft << ", volRight" << volRight;
+//				qCDebug(KMIX_LOG) << md->id() << ": " << "volLeft=" << volLeft << ", volRight" << volRight;
 
 			bool isMuted = volLeft==0 && ( vol.count() < 2 || volRight==0 ); // muted is "left and right muted" or "left muted when mono"
 			md->setMuted( isMuted );
@@ -403,7 +402,7 @@ int Mixer_OSS::readVolumeFromHW( const QString& id, shared_ptr<MixDevice> md )
 
 		               if ( volOld != volNew ) {
 		            	   controlChanged = true;
-		            	   //if ( md->id() == "0" ) kDebug() << "changed";
+		            	   //if ( md->id() == "0" ) qCDebug(KMIX_LOG) << "changed";
 		               }
 		        } // foreach
 			} // muted
@@ -431,7 +430,7 @@ int Mixer_OSS::readVolumeFromHW( const QString& id, shared_ptr<MixDevice> md )
 	{
 		if ( controlChanged )
 		{
-			//kDebug() << "FINE! " << ret;
+			//qCDebug(KMIX_LOG) << "FINE! " << ret;
 			return Mixer::OK;
 		}
 		else
@@ -441,7 +440,7 @@ int Mixer_OSS::readVolumeFromHW( const QString& id, shared_ptr<MixDevice> md )
 	}
 	else
 	{
-		//kDebug() << "SHIT! " << ret;
+		//qCDebug(KMIX_LOG) << "SHIT! " << ret;
 		return ret;
 	}
 }
