@@ -35,11 +35,8 @@ class QVBoxLayout;
 #include <QDragEnterEvent>
 #include <QMimeData>
 
-// KDE
-#include <kdebug.h>
-#include <kdialog.h>
-
 // KMix
+#include "dialogbase.h"
 #include "gui/guiprofile.h"
 #include "viewbase.h"
 
@@ -76,23 +73,23 @@ public:
    void dropped(DialogViewConfigurationWidget* list, int index, DialogViewConfigurationItem* item, bool sourceIsActiveList);
 
 protected:
-    virtual QMimeData* mimeData(const QList<QListWidgetItem*> items) const;
-    virtual bool dropMimeData(int index, const QMimeData * mimeData, Qt::DropAction action);
+    QMimeData* mimeData(const QList<QListWidgetItem*> items) const Q_DECL_OVERRIDE;
+    bool dropMimeData(int index, const QMimeData * mimeData, Qt::DropAction action) Q_DECL_OVERRIDE;
 
-    virtual Qt::DropActions supportedDropActions() const
+    Qt::DropActions supportedDropActions() const Q_DECL_OVERRIDE
     {
-        //kDebug() << "supportedDropActions!";
+        //qCDebug(KMIX_LOG) << "supportedDropActions!";
         return Qt::MoveAction;
     }
-    virtual QStringList mimeTypes() const
+    QStringList mimeTypes() const Q_DECL_OVERRIDE
     {
-        //kDebug() << "mimeTypes!";
+        //qCDebug(KMIX_LOG) << "mimeTypes!";
         return QStringList() << "application/x-kde-action-list";
     }
 
     // Skip internal dnd handling in QListWidget ---- how is one supposed to figure this out
     // without reading the QListWidget code !?
-    virtual void dropEvent(QDropEvent* ev) {
+    void dropEvent(QDropEvent* ev) Q_DECL_OVERRIDE {
         QAbstractItemView::dropEvent(ev);
     }
 
@@ -101,15 +98,13 @@ private:
 };
 
 
-class DialogViewConfiguration : public KDialog
+class DialogViewConfiguration : public DialogBase
 {
     Q_OBJECT
  public:
     DialogViewConfiguration(QWidget* parent, ViewBase& view);
     ~DialogViewConfiguration();
 
-
-  //  QSize sizeHint() const;
  public slots:
     void apply();
  
@@ -127,12 +122,9 @@ class DialogViewConfiguration : public KDialog
     void createPage();
     void addSpacer(int row, int col);
     void moveSelection(DialogViewConfigurationWidget* from, DialogViewConfigurationWidget* to);
-    QVBoxLayout* _layout;
     ViewBase&    _view;
-    QWidget * frame;
     QGridLayout *_glayout;
 
-    QLabel* qlb;
     QPushButton* moveLeftButton;
     QPushButton* moveRightButton;
 
